# Blure clip board image for macOS

Blur clip board image command line tool for macOS.

## Installation

```sh
pip install blur-clip-board-image-cli
```

## Usage

1. Copy image
2. Run this command `blur-clip-board-image`
    - Default blur rate is `8.5`
    - You can also select blur rate with argument like `blur-clip-board-image 10`
3. Paste image

## Licence

MIT